==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayRewriteRuleSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Rewrite rule set of an application gateway.
 * @property id Resource ID.
 * @property name Name of the rewrite rule set that is unique within an Application Gateway.
 * @property rewriteRules Rewrite rules in the rewrite rule set.
 */
public data class ApplicationGatewayRewriteRuleSetArgs(
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val rewriteRules: Output<List<ApplicationGatewayRewriteRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .rewriteRules(
                rewriteRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewayRewriteRuleSetArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayRewriteRuleSetArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var rewriteRules: Output<List<ApplicationGatewayRewriteRuleArgs>>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("dcoyckvjalnggiuh")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the rewrite rule set that is unique within an Application Gateway.
     */
    @JvmName("asfrpixqsqaduebf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Rewrite rules in the rewrite rule set.
     */
    @JvmName("klwtdripniyvrqmn")
    public suspend fun rewriteRules(`value`: Output<List<ApplicationGatewayRewriteRuleArgs>>) {
        this.rewriteRules = value
    }

    @JvmName("kowxssuqbgxkjudg")
    public suspend fun rewriteRules(vararg values: Output<ApplicationGatewayRewriteRuleArgs>) {
        this.rewriteRules = Output.all(values.asList())
    }

    /**
     * @param values Rewrite rules in the rewrite rule set.
     */
    @JvmName("hipkatfamkcupojv")
    public suspend fun rewriteRules(values: List<Output<ApplicationGatewayRewriteRuleArgs>>) {
        this.rewriteRules = Output.all(values)
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("srvlbqnadbogipls")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the rewrite rule set that is unique within an Application Gateway.
     */
    @JvmName("ntumqsbpjmasedek")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Rewrite rules in the rewrite rule set.
     */
    @JvmName("mhbkydxywrqqnioi")
    public suspend fun rewriteRules(`value`: List<ApplicationGatewayRewriteRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rewriteRules = mapped
    }

    /**
     * @param argument Rewrite rules in the rewrite rule set.
     */
    @JvmName("avvowivxddtfvsvt")
    public suspend
    fun rewriteRules(argument: List<suspend ApplicationGatewayRewriteRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayRewriteRuleArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.rewriteRules = mapped
    }

    /**
     * @param argument Rewrite rules in the rewrite rule set.
     */
    @JvmName("rbkvyuigqcswddjx")
    public suspend fun rewriteRules(
        vararg
        argument: suspend ApplicationGatewayRewriteRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayRewriteRuleArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.rewriteRules = mapped
    }

    /**
     * @param argument Rewrite rules in the rewrite rule set.
     */
    @JvmName("qmqtpilnhhbjmyfu")
    public suspend
    fun rewriteRules(argument: suspend ApplicationGatewayRewriteRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ApplicationGatewayRewriteRuleArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.rewriteRules = mapped
    }

    /**
     * @param values Rewrite rules in the rewrite rule set.
     */
    @JvmName("lgreohemegeivtsq")
    public suspend fun rewriteRules(vararg values: ApplicationGatewayRewriteRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rewriteRules = mapped
    }

    internal fun build(): ApplicationGatewayRewriteRuleSetArgs = ApplicationGatewayRewriteRuleSetArgs(
        id = id,
        name = name,
        rewriteRules = rewriteRules,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayRewriteRuleSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Rewrite rule set of an application gateway.
 * @property id Resource ID.
 * @property name Name of the rewrite rule set that is unique within an Application Gateway.
 * @property rewriteRules Rewrite rules in the rewrite rule set.
 */
public data class ApplicationGatewayRewriteRuleSetArgs(
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val rewriteRules: Output<List<ApplicationGatewayRewriteRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleSetArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .rewriteRules(
                rewriteRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewayRewriteRuleSetArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayRewriteRuleSetArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var rewriteRules: Output<List<ApplicationGatewayRewriteRuleArgs>>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("pvhqnlybswbyqddr")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the rewrite rule set that is unique within an Application Gateway.
     */
    @JvmName("cxlvybgjlhwaxevk")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Rewrite rules in the rewrite rule set.
     */
    @JvmName("qeykunmtabsykxsl")
    public suspend fun rewriteRules(`value`: Output<List<ApplicationGatewayRewriteRuleArgs>>) {
        this.rewriteRules = value
    }

    @JvmName("pykuinivijinllgr")
    public suspend fun rewriteRules(vararg values: Output<ApplicationGatewayRewriteRuleArgs>) {
        this.rewriteRules = Output.all(values.asList())
    }

    /**
     * @param values Rewrite rules in the rewrite rule set.
     */
    @JvmName("vdwkbrwkoitbtlmi")
    public suspend fun rewriteRules(values: List<Output<ApplicationGatewayRewriteRuleArgs>>) {
        this.rewriteRules = Output.all(values)
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("lnjbthsrpcrbwnpt")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the rewrite rule set that is unique within an Application Gateway.
     */
    @JvmName("vcafaskgbhbreyej")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Rewrite rules in the rewrite rule set.
     */
    @JvmName("jelamwsinosnptwi")
    public suspend fun rewriteRules(`value`: List<ApplicationGatewayRewriteRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rewriteRules = mapped
    }

    /**
     * @param argument Rewrite rules in the rewrite rule set.
     */
    @JvmName("ibdgxwyauclobphf")
    public suspend
    fun rewriteRules(argument: List<suspend ApplicationGatewayRewriteRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayRewriteRuleArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.rewriteRules = mapped
    }

    /**
     * @param argument Rewrite rules in the rewrite rule set.
     */
    @JvmName("jtumusrnxuwbfuyx")
    public suspend fun rewriteRules(
        vararg
        argument: suspend ApplicationGatewayRewriteRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayRewriteRuleArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.rewriteRules = mapped
    }

    /**
     * @param argument Rewrite rules in the rewrite rule set.
     */
    @JvmName("extrysmtmppbtwro")
    public suspend
    fun rewriteRules(argument: suspend ApplicationGatewayRewriteRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ApplicationGatewayRewriteRuleArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.rewriteRules = mapped
    }

    /**
     * @param values Rewrite rules in the rewrite rule set.
     */
    @JvmName("aljwdbhesnhcllry")
    public suspend fun rewriteRules(vararg values: ApplicationGatewayRewriteRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rewriteRules = mapped
    }

    internal fun build(): ApplicationGatewayRewriteRuleSetArgs = ApplicationGatewayRewriteRuleSetArgs(
        id = id,
        name = name,
        rewriteRules = rewriteRules,
    )
}
